@@ -33,7 +33,7 @@ typedef QSharedPointer<Resource> ResourcePtr;
  * In RSS, e.g. the feed channel itself and the items are
  * resources.
  */
-class SYNDICATION_EXPORT Resource : public Node
+class Resource : public Node
 {
     friend class Model;
 
@@ -76,7 +76,7 @@ public:
      *
      * @param other the node to compare this node to
      */
-    bool operator==(const Node &other) const override;
+    bool operator==(const Resource &other) const;
 
     /**
      * Used by visitors for double dispatch. See NodeVisitor
